# DataRestoreLocation

DataRestoreLocation describes the spec restore location of  Dataset
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**node_name** | **str** | NodeName describes the nodeName of restore if Path is  in the form of local://subpath | [optional] 
**path** | **str** | Path describes the path of restore, in the form of  local://subpath or pvc://&lt;pvcName&gt;/subpath | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


